Author: linus
Date: 2007-09-12 09:45:16-0700
New Revision: 13545
Modified:
trunk/src_new/org/argouml/i18n/label.properties
trunk/src_new/org/argouml/ui/AbstractArgoJPanel.java
trunk/src_new/org/argouml/ui/StylePanel.java
trunk/src_new/org/argouml/uml/diagram/use_case/ui/StylePanelFigUseCase.java
trunk/src_new/org/argouml/uml/ui/PropPanel.java
trunk/src_new/org/argouml/uml/ui/UMLRadioButtonPanel.java
trunk/src_new/org/argouml/uml/ui/behavior/common_behavior/PropPanelLinkEnd.java
trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelCallEvent.java
trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelChangeEvent.java
trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelCompositeState.java
trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelEvent.java
trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelFinalState.java
trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelGuard.java
trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelPseudostate.java
trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSignalEvent.java
trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSimpleState.java
trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelStateMachine.java
trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelStubState.java
trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSubmachineState.java
trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSynchState.java
trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelTimeEvent.java
trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelTransition.java
trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelActor.java
trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelExtend.java
trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelExtensionPoint.java
trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelInclude.java
trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelUseCase.java
trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelAssociation.java
trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelAssociationClass.java
trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelAssociationEnd.java
trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelClass.java
trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelModelElement.java
trunk/src_new/org/argouml/uml/ui/model_management/PropPanelPackage.java
Log:
Committed changes by Harald Braun.
Also made some clarifications by editing java doc and local
variables.
Modified: trunk/src_new/org/argouml/i18n/label.properties
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/i18n/label.properties?view=diff&rev=13545&p1=trunk/src_new/org/argouml/i18n/label.properties&p2=trunk/src_new/org/argouml/i18n/label.properties&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/i18n/label.properties (original)
+++ trunk/src_new/org/argouml/i18n/label.properties 2007-09-12 09:45:16-0700
@@ -71,6 +71,7 @@
label.by = , by
label.call-event = Call Event
label.change = Change Expression
+label.change.event=Change event
label.changeability = Changeability:
label.changeability-addonly = addOnly
label.changeability-changeable = changeable
@@ -93,11 +94,14 @@
label.comment.name = Comment Name:
label.component = Component
label.components = Components:
+label.composite-state=Composite State
label.concurrency = Concurrency:
label.concurrency-concurrent = concurrent
label.concurrency-guarded = guarded
label.concurrency-sequential = sequential
label.concurrent = Concurrent
+label.concurrent.region=Concurrent Region
+label.concurrent.composite.state=Concurrent Composite State
label.condition = Condition:
label.connections = Connections:
label.constrained-elements = Constrained Elements:
@@ -163,6 +167,7 @@
label.extension-points = Extension Points:
label.features = Features:
label.fill = Fill
+label.final.state=Final State
label.fonts.big = Big size
label.fonts.huge = Huge size
label.fonts.normal = Normal size
@@ -254,6 +259,7 @@
label.projectbrowser-title = Untitled
label.project.description= Project Description:
label.properties-pane = Properties Pane
+label.pseudostate=Pseudostate
label.pseudostate-kind = Pseudostate Kind:
label.pseudostate.choice = Choice State
label.pseudostate.deephistory = Deep History State
@@ -306,6 +312,8 @@
label.show-types = Show types and parameters
label.show-visibility = Show visibility
label.signal = Signal:
+label.signal.event=Signal event
+label.simple.state=Simple State
label.since = Since:
label.since-p = <Since>
label.smooth-edges = Smooth edges of diagram lines and text
@@ -327,6 +335,7 @@
label.stimili-received = Stimuli received:
label.stimili-sent = Stimuli sent:
label.strip-diagrams = Strip (non-standard) diagrams from XMI file during import
+label.stub.state=Stub State
label.style-pane = Style Pane
label.stylepane.bounds = Bounds
label.stylepane.custom = Custom
@@ -339,7 +348,7 @@
label.stylepane.path = Path
label.stylepane.rounding = Rounding
label.submachine = Submachine:
-label.submachinestate = Submachine States:
+label.submachinestate = Submachine State:
label.subvertex = Subvertices:
label.supplier-dependencies = Supplier Dependencies:
label.suppliers = Suppliers:
@@ -353,6 +362,7 @@
label.target = Target
label.target-flows = Target Flows:
label.targetscope-classifier = static
+label.time.event=Time event
label.todo-pane = ToDo Pane
label.todopane.item = {0} Item
label.todopane.items = {0} Items
Modified: trunk/src_new/org/argouml/ui/AbstractArgoJPanel.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/ui/AbstractArgoJPanel.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/ui/AbstractArgoJPanel.java&p2=trunk/src_new/org/argouml/ui/AbstractArgoJPanel.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/ui/AbstractArgoJPanel.java (original)
+++ trunk/src_new/org/argouml/ui/AbstractArgoJPanel.java 2007-09-12 09:45:16-0700
@@ -1,5 +1,5 @@
// $Id$
-// Copyright (c) 1996-2006 The Regents of the University of California. All
+// Copyright (c) 1996-2007 The Regents of the University of California. All
// Rights Reserved. Permission to use, copy, modify, and distribute this
// software and its documentation without fee, and without a written
// agreement is hereby granted, provided that the above copyright notice
@@ -97,22 +97,22 @@
/**
* The constructor.
*
- * @param tag the name
+ * @param title The name as a localized string.
*/
// TODO: Investigate in what cases is the tag a localized string
// and in what cases is it a key to be localized?
- public AbstractArgoJPanel(String tag) {
- this(tag, false);
+ public AbstractArgoJPanel(String title) {
+ this(title, false);
}
/**
* The constructor.
*
- * @param tag The name (to be localized).
+ * @param title The name (a localized string).
* @param t if true, remove tab from parent JTabbedPane
*/
// TODO: Investigate in what cases is the tag a localized string
- // and in what cases is it a key to be localized? - Harold Braun via Linus 20070521
+ // and in what cases is it a key to be localized? - Harald Braun via Linus 20070521
// Answer: There are three cases: 1) unlocalized string, 2) localized
// string, and 3) property/tag name. Of the 100+ subclasses, the
// overwhelming majority fall into category #1. Category #3 includes
@@ -121,8 +121,12 @@
// and TabStereotype. The breakdown is approximately 80+/10/6. The
// analysis is easy. Fixing the 90+ property panels will be more work.
// - tfm - 20070517
- public AbstractArgoJPanel(String tag, boolean t) {
- setTitle(tag);
+ // The conclusion is that the title shall be a localized string fixing
+ // all classes from category #1. Harald Braun has already started the
+ // work. I will merge in his changes. Firstly I will clarify this class.
+ // Linus 2007-09-11.
+ public AbstractArgoJPanel(String title, boolean t) {
+ setTitle(title);
tear = t;
}
@@ -153,14 +157,14 @@
// accessors
/**
- * @return The key (to be localized) for the title of the panel.
+ * @return The title of the panel, a localized string.
*/
public String getTitle() {
return title;
}
/**
- * @param t The key (to be localized) of the title.
+ * @param t The title, a localized string.
*/
public void setTitle(String t) {
title = t;
@@ -184,6 +188,8 @@
JDialog f = new JDialog(ArgoFrame.getInstance());
f.getContentPane().setLayout(new BorderLayout());
+ // TODO: Once we have fixed all subclasses the title will
+ // always be localized so this localization can be removed.
f.setTitle(Translator.localize(title));
AbstractArgoJPanel newPanel = (AbstractArgoJPanel) clone();
if (newPanel == null) {
@@ -204,6 +210,8 @@
// it.setTarget(me.getTarget());
// }
+ // TODO: Once we have fixed all subclasses the title will
+ // always be localized so this localization can be removed.
newPanel.setTitle(Translator.localize(title));
f.getContentPane().add(newPanel, BorderLayout.CENTER);
Modified: trunk/src_new/org/argouml/ui/StylePanel.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/ui/StylePanel.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/ui/StylePanel.java&p2=trunk/src_new/org/argouml/ui/StylePanel.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/diagram/use_case/ui/StylePanelFigUseCase.java (original)
+++ trunk/src_new/org/argouml/uml/diagram/use_case/ui/StylePanelFigUseCase.java 2007-09-12 09:45:16-0700
@@ -1,5 +1,5 @@
// $Id$
-// Copyright (c) 1996-2006 The Regents of the University of California. All
+// Copyright (c) 1996-2007 The Regents of the University of California. All
// Rights Reserved. Permission to use, copy, modify, and distribute this
// software and its documentation without fee, and without a written
// agreement is hereby granted, provided that the above copyright notice
@@ -29,6 +29,7 @@
import javax.swing.JCheckBox;
import org.argouml.ui.StylePanelFigNodeModelElement;
+import org.argouml.i18n.Translator;
/**
* A class to provide a style panel for use cases.<p>
@@ -43,7 +44,8 @@
/**
* The check box for toggling the visibility of extension points.
*/
- private JCheckBox epCheckBox = new JCheckBox("Extension Points");
+ private JCheckBox epCheckBox =
+ new JCheckBox(Translator.localize("checkbox.extension-points"));
/**
* Flag to indicate that a refresh is going on.
@@ -88,8 +90,7 @@
/**
* Something has changed, check if its the check box.<p>
*
- * @param e
- * The event that triggeed us.
+ * @param e The event that triggered us.
*
* @see java.awt.event.ItemListener#itemStateChanged(java.awt.event.ItemEvent)
*/
Modified: trunk/src_new/org/argouml/uml/ui/PropPanel.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/PropPanel.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/PropPanel.java&p2=trunk/src_new/org/argouml/uml/ui/PropPanel.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/PropPanel.java (original)
+++ trunk/src_new/org/argouml/uml/ui/PropPanel.java 2007-09-12 09:45:16-0700
@@ -76,7 +76,8 @@
* The property panel is {@link org.tigris.swidgets.LabelledLayout} layed out as
* a number (specified in the constructor) of equally sized panels that split
* the available space. Each panel has a column of "captions" and matching
- * column of "fields" which are laid out indepently from the other panels.<p>
+ * column of "fields" which are laid out independently from the other
+ * panels.<p>
*
* The Properties panels for UML Model Elements are structured in an inheritance
* hierarchy that matches the UML metamodel.
@@ -103,8 +104,17 @@
private JPanel buttonPanel = new JPanel(new GridLayout());
private JLabel titleLabel;
-
- private List actions = new ArrayList();
+
+ /**
+ * A list with "actions".<p>
+ *
+ * Action in this respect are one of:<ul>
+ * <li> {@link Action}
+ * <li> {@link JButton}
+ * <li> {@link Object}[]
+ * </ul>
+ */
+ private List actions = new ArrayList<Action>();
private static Font stdFont =
LookAndFeelMgr.getInstance().getStandardFont();
@@ -114,13 +124,13 @@
*
* @param icon
* The icon to display for the panel
- * @param title
- * The title of the panel
+ * @param label
+ * The label for the title of the panel (to be localized).
* @param orientation
* the orientation
*/
- public PropPanel(String title, ImageIcon icon, Orientation orientation) {
- super(title);
+ public PropPanel(String label, ImageIcon icon, Orientation orientation) {
+ super(Translator.localize(label));
setOrientation(orientation);
LabelledLayout layout =
@@ -129,9 +139,9 @@
setLayout(layout);
if (icon != null) {
- setTitleLabel(new JLabel(title, icon, SwingConstants.LEFT));
+ setTitleLabel(new JLabel(Translator.localize(label), icon, SwingConstants.LEFT));
} else {
- setTitleLabel(new JLabel(title));
+ setTitleLabel(new JLabel(Translator.localize(label)));
}
titleLabel.setLabelFor(buttonPanel);
add(titleLabel);
@@ -144,13 +154,13 @@
* Constructs a new Proppanel without an icon. If there is an icon it's
* updated at runtime via settarget.<p>
*
- * @param title
- * the title
+ * @param label
+ * The label for the title of the PropPanel (to be localized).
* @param orientation
* the orientation
*/
- public PropPanel(String title, Orientation orientation) {
- this(title, null, orientation);
+ public PropPanel(String label, Orientation orientation) {
+ this(label, null, orientation);
}
/*
@@ -168,7 +178,7 @@
* the action which will be used in the toolbar button.
*/
protected void addAction(Action action) {
- this.actions.add(action);
+ actions.add(action);
}
/**
@@ -196,7 +206,7 @@
* @param actionArray the Actions.
*/
protected void addAction(Object[] actionArray) {
- this.actions.add(actionArray);
+ actions.add(actionArray);
}
public void buildToolbar() {
@@ -239,7 +249,7 @@
* @return the label added
*/
public JLabel addField(String label, Component component) {
- JLabel jlabel = new JLabel(label);
+ JLabel jlabel = new JLabel(Translator.localize(label));
jlabel.setFont(stdFont);
component.setFont(stdFont);
jlabel.setLabelFor(component);
@@ -262,10 +272,10 @@
*/
public JLabel addFieldAfter(String label, Component component,
Component afterComponent) {
- int nComponent = this.getComponentCount();
+ int nComponent = getComponentCount();
for (int i = 0; i < nComponent; ++i) {
if (getComponent(i) == afterComponent) {
- JLabel jlabel = new JLabel(label);
+ JLabel jlabel = new JLabel(Translator.localize(label));
jlabel.setFont(stdFont);
component.setFont(stdFont);
jlabel.setLabelFor(component);
@@ -291,10 +301,10 @@
*/
public JLabel addFieldBefore(String label, Component component,
Component beforeComponent) {
- int nComponent = this.getComponentCount();
+ int nComponent = getComponentCount();
for (int i = 0; i < nComponent; ++i) {
if (getComponent(i) == beforeComponent) {
- JLabel jlabel = new JLabel(label);
+ JLabel jlabel = new JLabel(Translator.localize(label));
jlabel.setFont(stdFont);
component.setFont(stdFont);
jlabel.setLabelFor(component);
@@ -429,7 +439,7 @@
}
/**
- * This method can be overriden in derived Panels where the appropriate
+ * This method can be overridden in derived Panels where the appropriate
* namespace for display may not be the same as the namespace of the target.
*
* @return the namespace
@@ -579,7 +589,7 @@
* the title of the panel shown at the top
*/
protected void setTitleLabel(JLabel theTitleLabel) {
- this.titleLabel = theTitleLabel;
+ titleLabel = theTitleLabel;
titleLabel.setFont(stdFont);
}
@@ -592,7 +602,7 @@
protected JPanel createBorderPanel(String title) {
JPanel panel = new JPanel(new GridLayout2());
- TitledBorder border = new TitledBorder(title);
+ TitledBorder border = new TitledBorder(Translator.localize(title));
border.setTitleFont(stdFont);
panel.setBorder(border);
return panel;
Modified: trunk/src_new/org/argouml/uml/ui/UMLRadioButtonPanel.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/UMLRadioButtonPanel.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/UMLRadioButtonPanel.java&p2=trunk/src_new/org/argouml/uml/ui/UMLRadioButtonPanel.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/UMLRadioButtonPanel.java (original)
+++ trunk/src_new/org/argouml/uml/ui/UMLRadioButtonPanel.java 2007-09-12 09:45:16-0700
@@ -41,6 +41,7 @@
import javax.swing.border.TitledBorder;
import org.argouml.model.Model;
+import org.argouml.i18n.Translator;
import org.argouml.ui.LookAndFeelMgr;
import org.argouml.ui.targetmanager.TargetEvent;
import org.argouml.ui.targetmanager.TargetListener;
@@ -93,10 +94,10 @@
* the name of the MEvent that is fired when the property that it
* shows changes value.
* @param setAction
- * the action that should be registred with the buttons and
+ * the action that should be registered with the buttons and
* that's executed when one of the buttons is pressed.
* @param horizontal
- * when true the buttons should be layed out horizontaly.
+ * when true the buttons should be laid out horizontally.
*/
public UMLRadioButtonPanel(
boolean isDoubleBuffered,
@@ -108,8 +109,8 @@
super(isDoubleBuffered);
setLayout(horizontal ? new GridLayout() : new GridLayout(0, 1));
setDoubleBuffered(true);
- if (title != null) {
- TitledBorder border = new TitledBorder(title);
+ if (Translator.localize(title) != null) {
+ TitledBorder border = new TitledBorder(Translator.localize(title));
border.setTitleFont(stdFont);
setBorder(border);
}
@@ -128,12 +129,12 @@
* logically recognize the button.
* @param thePropertySetName
* the name of the MEvent that is fired when the property that is
- * showns changes value.
+ * shown changes value.
* @param setAction
- * the action that should be registred with the buttons and
+ * the action that should be registered with the buttons and
* that's executed when one of the buttons is pressed
* @param horizontal
- * when true the buttons should be layed out horizontaly.
+ * when true the buttons should be laid out horizontally.
*/
public UMLRadioButtonPanel(String title,
List<String[]> labeltextsActioncommands,
@@ -159,10 +160,10 @@
* the name of the MEvent that is fired when the property that it
* shows changes value.
* @param setAction
- * the action that should be registred with the buttons and
+ * the action that should be registered with the buttons and
* that's executed when one of the buttons is pressed.
* @param horizontal
- * when true the buttons should be layed out horizontaly.
+ * when true the buttons should be laid out horizontally.
* @deprecated for 0.25.4 by tfmorris. Use List<String[]> form of
* constructor.
*/
@@ -198,10 +199,10 @@
* the name of the MEvent that is fired when the property that is
* showns changes value.
* @param setAction
- * the action that should be registred with the buttons and
+ * the action that should be registered with the buttons and
* that's executed when one of the buttons is pressed
* @param horizontal
- * when true the buttons should be layed out horizontaly.
+ * when true the buttons should be laid out horizontally.
* @deprecated for 0.25.4 by tfmorris. Use List<String[]> form of
* constructor. See
* {@link UMLParameterDirectionKindRadioButtonPanel} for an
@@ -227,7 +228,7 @@
* the actioncommand that permits the setAction to logically
* recognize the button.
* @param setAction
- * the action that should be registred with the buttons and
+ * the action that should be registered with the buttons and
* that's executed when one of the buttons is pressed
*/
private void setButtons(List<String[]> labeltextsActioncommands,
@@ -309,7 +310,7 @@
/**
* Builds the model. That is: it selects the radiobutton showing the value
- * of the attribute shown. The name of this method is choosen to be
+ * of the attribute shown. The name of this method is chosen to be
* compliant with for example UMLModelElementListModel2
*/
public abstract void buildModel();
Modified: trunk/src_new/org/argouml/uml/ui/behavior/common_behavior/PropPanelLinkEnd.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/behavior/common_behavior/PropPanelLinkEnd.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/behavior/common_behavior/PropPanelLinkEnd.java&p2=trunk/src_new/org/argouml/uml/ui/behavior/common_behavior/PropPanelLinkEnd.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/behavior/common_behavior/PropPanelLinkEnd.java (original)
+++ trunk/src_new/org/argouml/uml/ui/behavior/common_behavior/PropPanelLinkEnd.java 2007-09-12 09:45:16-0700
@@ -1,5 +1,5 @@
// $Id$
-// Copyright (c) 1996-2006 The Regents of the University of California. All
+// Copyright (c) 1996-2007 The Regents of the University of California. All
// Rights Reserved. Permission to use, copy, modify, and distribute this
// software and its documentation without fee, and without a written
// agreement is hereby granted, provided that the above copyright notice
@@ -30,7 +30,6 @@
import javax.swing.Action;
import org.argouml.application.helpers.ResourceLoaderWrapper;
-import org.argouml.i18n.Translator;
import org.argouml.model.Model;
import org.argouml.uml.ui.AbstractActionNavigate;
import org.argouml.uml.ui.ActionNavigateContainerElement;
@@ -53,12 +52,13 @@
private static final long serialVersionUID = 666929091194719951L;
/**
- * Contruct a property panel for a Link End.
+ * Construct a property panel for a Link End.
*/
public PropPanelLinkEnd() {
- super("Link End", lookupIcon("AssociationEnd"),
+ super("label.association-link-end",
+ lookupIcon("AssociationEnd"),
ConfigLoader.getTabPropsOrientation());
- addField(Translator.localize("label.name"),
+ addField("label.name",
getNameTextField());
addSeparator();
Modified: trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelCallEvent.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelCallEvent.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelCallEvent.java&p2=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelCallEvent.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelCallEvent.java (original)
+++ trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelCallEvent.java 2007-09-12 09:45:16-0700
@@ -1,5 +1,5 @@
// $Id$
-// Copyright (c) 1996-2006 The Regents of the University of California. All
+// Copyright (c) 1996-2007 The Regents of the University of California. All
// Rights Reserved. Permission to use, copy, modify, and distribute this
// software and its documentation without fee, and without a written
// agreement is hereby granted, provided that the above copyright notice
@@ -51,7 +51,7 @@
*
*/
public PropPanelCallEvent() {
- super("Call event", lookupIcon("CallEvent"),
+ super("label.call-event", lookupIcon("CallEvent"),
ConfigLoader.getTabPropsOrientation());
}
@@ -64,7 +64,7 @@
UMLSearchableComboBox operationComboBox =
new UMLCallEventOperationComboBox2(
new UMLCallEventOperationComboBoxModel());
- addField(Translator.localize("label.operations"),
+ addField("label.operations",
new UMLComboBoxNavigator(
Translator.localize("label.operation.navigate.tooltip"),
operationComboBox));
Modified: trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelChangeEvent.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelChangeEvent.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelChangeEvent.java&p2=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelChangeEvent.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelChangeEvent.java (original)
+++ trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelChangeEvent.java 2007-09-12 09:45:16-0700
@@ -1,5 +1,5 @@
// $Id$
-// Copyright (c) 1996-2006 The Regents of the University of California. All
+// Copyright (c) 1996-2007 The Regents of the University of California. All
// Rights Reserved. Permission to use, copy, modify, and distribute this
// software and its documentation without fee, and without a written
// agreement is hereby granted, provided that the above copyright notice
@@ -27,7 +27,6 @@
import javax.swing.JPanel;
import javax.swing.JScrollPane;
-import org.argouml.i18n.Translator;
import org.argouml.uml.ui.UMLExpressionBodyField;
import org.argouml.uml.ui.UMLExpressionLanguageField;
import org.argouml.uml.ui.UMLExpressionModel2;
@@ -45,7 +44,7 @@
*
*/
public PropPanelChangeEvent() {
- super("Change event", lookupIcon("ChangeEvent"),
+ super("label.change.event", lookupIcon("ChangeEvent"),
ConfigLoader.getTabPropsOrientation());
}
@@ -57,8 +56,7 @@
UMLExpressionModel2 changeModel = new UMLChangeExpressionModel(
this, "changeExpression");
- JPanel changePanel = createBorderPanel(Translator
- .localize("label.change"));
+ JPanel changePanel = createBorderPanel("label.change");
changePanel.add(new JScrollPane(new UMLExpressionBodyField(
changeModel, true)));
changePanel.add(new UMLExpressionLanguageField(changeModel,
Modified: trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelCompositeState.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelCompositeState.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelCompositeState.java&p2=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelCompositeState.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelCompositeState.java (original)
+++ trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelCompositeState.java 2007-09-12 09:45:16-0700
@@ -1,5 +1,5 @@
// $Id$
-// Copyright (c) 1996-2006 The Regents of the University of California. All
+// Copyright (c) 1996-2007 The Regents of the University of California. All
// Rights Reserved. Permission to use, copy, modify, and distribute this
// software and its documentation without fee, and without a written
// agreement is hereby granted, provided that the above copyright notice
@@ -29,7 +29,6 @@
import javax.swing.JList;
import javax.swing.JScrollPane;
-import org.argouml.i18n.Translator;
import org.argouml.model.Model;
import org.argouml.ui.targetmanager.TargetManager;
import org.argouml.uml.diagram.ui.ActionAddConcurrentRegion;
@@ -70,35 +69,35 @@
*
*/
public PropPanelCompositeState() {
- super("Composite State", lookupIcon("CompositeState"),
+ super("label.composite-state", lookupIcon("CompositeState"),
ConfigLoader.getTabPropsOrientation());
initialize();
- addField(Translator.localize("label.name"),
+ addField("label.name",
getNameTextField());
- addField(Translator.localize("label.container"),
+ addField("label.container",
getContainerScroll());
- /*addField(Translator.localize("label.modifiers"),
+ /*addField("label.modifiers",
new UMLCompositeStateConcurrentCheckBox());*/
- addField(Translator.localize("label.entry"),
+ addField("label.entry",
getEntryScroll());
- addField(Translator.localize("label.exit"),
+ addField("label.exit",
getExitScroll());
- addField(Translator.localize("label.do-activity"),
+ addField("label.do-activity",
getDoScroll());
addSeparator();
- addField(Translator.localize("label.incoming"),
+ addField("label.incoming",
getIncomingScroll());
- addField(Translator.localize("label.outgoing"),
+ addField("label.outgoing",
getOutgoingScroll());
- addField(Translator.localize("label.internal-transitions"),
+ addField("label.internal-transitions",
getInternalTransitionsScroll());
addSeparator();
- addField(Translator.localize("label.subvertex"),
+ addField("label.subvertex",
new JScrollPane(subverticesList));
}
@@ -136,11 +135,11 @@
updateExtraButtons();
Object target = TargetManager.getInstance().getModelTarget();
if (Model.getFacade().isAConcurrentRegion(target)) {
- getTitleLabel().setText("Concurrent Region");
+ getTitleLabel().setText("label.concurrent.region");
} else if (Model.getFacade().isConcurrent(target)) {
- getTitleLabel().setText("Concurrent Composite State");
+ getTitleLabel().setText("label.concurrent.composite.state");
} else {
- getTitleLabel().setText("Composite State");
+ getTitleLabel().setText("label.composite-state");
}
}
Modified: trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelEvent.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelEvent.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelEvent.java&p2=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelEvent.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelEvent.java (original)
+++ trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelEvent.java 2007-09-12 09:45:16-0700
@@ -28,7 +28,6 @@
import javax.swing.JList;
import javax.swing.JScrollPane;
-import org.argouml.i18n.Translator;
import org.argouml.uml.ui.ActionNavigateContainerElement;
import org.argouml.uml.ui.UMLLinkedList;
import org.argouml.uml.ui.UMLMutableLinkedList;
@@ -68,18 +67,18 @@
paramScroll = getParameterScroll();
- addField(Translator.localize("label.name"),
+ addField("label.name",
getNameTextField());
- addField(Translator.localize("label.namespace"),
+ addField("label.namespace",
getNamespaceSelector());
addSeparator();
- addField(Translator.localize("label.parameters"),
+ addField("label.parameters",
getParameterScroll());
JList transitionList = new UMLLinkedList(
new UMLEventTransitionListModel());
transitionList.setVisibleRowCount(2);
- addField(Translator.localize("label.transition"),
+ addField("label.transition",
new JScrollPane(transitionList));
addSeparator();
Modified: trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelFinalState.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelFinalState.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelFinalState.java&p2=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelFinalState.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelFinalState.java (original)
+++ trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelFinalState.java 2007-09-12 09:45:16-0700
@@ -1,5 +1,5 @@
// $Id$
-// Copyright (c) 1996-2006 The Regents of the University of California. All
+// Copyright (c) 1996-2007 The Regents of the University of California. All
// Rights Reserved. Permission to use, copy, modify, and distribute this
// software and its documentation without fee, and without a written
// agreement is hereby granted, provided that the above copyright notice
@@ -24,7 +24,6 @@
package org.argouml.uml.ui.behavior.state_machines;
-import org.argouml.i18n.Translator;
import org.argouml.util.ConfigLoader;
/**
@@ -43,23 +42,23 @@
* Construct a new property panel for a Final State.
*/
public PropPanelFinalState() {
- super("Final State", lookupIcon("FinalState"),
+ super("label.final.state", lookupIcon("FinalState"),
ConfigLoader.getTabPropsOrientation());
- addField(Translator.localize("label.name"),
+ addField("label.name",
getNameTextField());
- addField(Translator.localize("label.container"),
+ addField("label.container",
getContainerScroll());
- addField(Translator.localize("label.entry"),
+ addField("label.entry",
getEntryScroll());
- addField(Translator.localize("label.do-activity"),
+ addField("label.do-activity",
getDoScroll());
addSeparator();
- addField(Translator.localize("label.incoming"),
+ addField("label.incoming",
getIncomingScroll());
- addField(Translator.localize("label.internal-transitions"),
+ addField("label.internal-transitions",
getInternalTransitionsScroll());
}
Modified: trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelGuard.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelGuard.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelGuard.java&p2=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelGuard.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelGuard.java (original)
+++ trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelGuard.java 2007-09-12 09:45:16-0700
@@ -28,7 +28,6 @@
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
-import org.argouml.i18n.Translator;
import org.argouml.ui.LookAndFeelMgr;
import org.argouml.uml.ui.ActionNavigateTransition;
import org.argouml.uml.ui.UMLExpressionBodyField;
@@ -57,17 +56,16 @@
*
*/
public PropPanelGuard() {
- super("Guard", ConfigLoader.getTabPropsOrientation());
+ super("label.guard", ConfigLoader.getTabPropsOrientation());
- addField(Translator.localize("label.name"), getNameTextField());
+ addField("label.name", getNameTextField());
- addField(Translator.localize("label.transition"), new JScrollPane(
+ addField("label.transition", new JScrollPane(
getSingleRowScroll(new UMLGuardTransitionListModel())));
addSeparator();
- JPanel exprPanel = createBorderPanel(Translator
- .localize("label.expression"));
+ JPanel exprPanel = createBorderPanel("label.expression");
UMLExpressionModel2 expressionModel = new UMLExpressionExpressionModel(
this, "expression");
JTextArea ebf = new UMLExpressionBodyField(expressionModel, true);
Modified: trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelPseudostate.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelPseudostate.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelPseudostate.java&p2=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelPseudostate.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelPseudostate.java (original)
+++ trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelPseudostate.java 2007-09-12 09:45:16-0700
@@ -48,18 +48,18 @@
* Construct a new property panel for a PseudoState (branch, fork, etc).
*/
public PropPanelPseudostate() {
- super("Pseudostate", null, ConfigLoader.getTabPropsOrientation());
+ super("label.pseudostate", null, ConfigLoader.getTabPropsOrientation());
- addField(Translator.localize("label.name"),
+ addField("label.name",
getNameTextField());
- addField(Translator.localize("label.container"),
+ addField("label.container",
getContainerScroll());
addSeparator();
- addField(Translator.localize("label.incoming"),
+ addField("label.incoming",
getIncomingScroll());
- addField(Translator.localize("label.outgoing"),
+ addField("label.outgoing",
getOutgoingScroll());
TargetManager.getInstance().addTargetListener(this);
@@ -82,33 +82,27 @@
}
if (Model.getFacade().equalsPseudostateKind(kind,
Model.getPseudostateKind().getJoin())) {
- getTitleLabel().setText(
- Translator.localize("label.pseudostate.join"));
+ getTitleLabel().setText("label.pseudostate.join");
}
if (Model.getFacade().equalsPseudostateKind(kind,
Model.getPseudostateKind().getChoice())) {
- getTitleLabel().setText(
- Translator.localize("label.pseudostate.choice"));
+ getTitleLabel().setText("label.pseudostate.choice");
}
if (Model.getFacade().equalsPseudostateKind(kind,
Model.getPseudostateKind().getDeepHistory())) {
- getTitleLabel().setText(
- Translator.localize("label.pseudostate.deephistory"));
+ getTitleLabel().setText("label.pseudostate.deephistory");
}
if (Model.getFacade().equalsPseudostateKind(kind,
Model.getPseudostateKind().getShallowHistory())) {
- getTitleLabel().setText(
- Translator.localize("label.pseudostate.shallowhistory"));
+ getTitleLabel().setText("label.pseudostate.shallowhistory");
}
if (Model.getFacade().equalsPseudostateKind(kind,
Model.getPseudostateKind().getInitial())) {
- getTitleLabel().setText(
- Translator.localize("label.pseudostate.initial"));
+ getTitleLabel().setText("label.pseudostate.initial");
}
if (Model.getFacade().equalsPseudostateKind(kind,
Model.getPseudostateKind().getJunction())) {
- getTitleLabel().setText(
- Translator.localize("label.pseudostate.junction"));
+ getTitleLabel().setText("label.pseudostate.junction");
}
Icon icon =
ResourceLoaderWrapper.getInstance().lookupIcon(target);
Modified: trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSignalEvent.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSignalEvent.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSignalEvent.java&p2=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSignalEvent.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSignalEvent.java (original)
+++ trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSignalEvent.java 2007-09-12 09:45:16-0700
@@ -1,5 +1,5 @@
// $Id$
-// Copyright (c) 1996-2006 The Regents of the University of California. All
+// Copyright (c) 1996-2007 The Regents of the University of California. All
// Rights Reserved. Permission to use, copy, modify, and distribute this
// software and its documentation without fee, and without a written
// agreement is hereby granted, provided that the above copyright notice
@@ -27,7 +27,6 @@
import javax.swing.JList;
import javax.swing.JScrollPane;
-import org.argouml.i18n.Translator;
import org.argouml.uml.ui.foundation.core.ActionNewParameter;
import org.argouml.util.ConfigLoader;
@@ -44,7 +43,7 @@
*
*/
public PropPanelSignalEvent() {
- super("Signal event", lookupIcon("SignalEvent"),
+ super("label.signal.event", lookupIcon("SignalEvent"),
ConfigLoader.getTabPropsOrientation());
}
@@ -57,7 +56,7 @@
JList signalList = new UMLSignalEventSignalList(
new UMLSignalEventSignalListModel());
signalList.setVisibleRowCount(1);
- addField(Translator.localize("label.signal"),
+ addField("label.signal",
new JScrollPane(signalList));
addAction(new ActionNewParameter());
Modified: trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSimpleState.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSimpleState.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSimpleState.java&p2=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSimpleState.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSimpleState.java (original)
+++ trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSimpleState.java 2007-09-12 09:45:16-0700
@@ -1,5 +1,5 @@
// $Id$
-// Copyright (c) 1996-2006 The Regents of the University of California. All
+// Copyright (c) 1996-2007 The Regents of the University of California. All
// Rights Reserved. Permission to use, copy, modify, and distribute this
// software and its documentation without fee, and without a written
// agreement is hereby granted, provided that the above copyright notice
@@ -26,7 +26,6 @@
import javax.swing.ImageIcon;
-import org.argouml.i18n.Translator;
import org.argouml.util.ConfigLoader;
import org.tigris.swidgets.Orientation;
@@ -46,7 +45,7 @@
* Construct a new default property panel for a Simple State.
*/
public PropPanelSimpleState() {
- this("Simple State", lookupIcon("SimpleState"),
+ this("label.simple.state", lookupIcon("SimpleState"),
ConfigLoader.getTabPropsOrientation());
}
@@ -62,26 +61,26 @@
Orientation orientation) {
super(name, icon, orientation);
- addField(Translator.localize("label.name"),
+ addField("label.name",
getNameTextField());
- addField(Translator.localize("label.container"),
+ addField("label.container",
getContainerScroll());
- addField(Translator.localize("label.entry"),
+ addField("label.entry",
getEntryScroll());
- addField(Translator.localize("label.exit"),
+ addField("label.exit",
getExitScroll());
- addField(Translator.localize("label.do-activity"),
+ addField("label.do-activity",
getDoScroll());
- addField(Translator.localize("label.deferrable"),
+ addField("label.deferrable",
getDeferrableEventsScroll());
addSeparator();
- addField(Translator.localize("label.incoming"),
+ addField("label.incoming",
getIncomingScroll());
- addField(Translator.localize("label.outgoing"),
+ addField("label.outgoing",
getOutgoingScroll());
- addField(Translator.localize("label.internal-transitions"),
+ addField("label.internal-transitions",
getInternalTransitionsScroll());
}
Modified: trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelStateMachine.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelStateMachine.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelStateMachine.java&p2=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelStateMachine.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelStateMachine.java (original)
+++ trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelStateMachine.java 2007-09-12 09:45:16-0700
@@ -1,5 +1,5 @@
// $Id$
-// Copyright (c) 1996-2006 The Regents of the University of California. All
+// Copyright (c) 1996-2007 The Regents of the University of California. All
// Rights Reserved. Permission to use, copy, modify, and distribute this
// software and its documentation without fee, and without a written
// agreement is hereby granted, provided that the above copyright notice
@@ -55,7 +55,7 @@
* Constructor for PropPanelStateMachine.
*/
public PropPanelStateMachine() {
- this("StateMachine", ConfigLoader.getTabPropsOrientation());
+ this("label.statemachine", ConfigLoader.getTabPropsOrientation());
}
@@ -71,12 +71,12 @@
}
/**
- * Initialise the panel with fields and stuff.
+ * Initialize the panel with fields and stuff.
*/
protected void initialize() {
- addField(Translator.localize("label.name"),
+ addField("label.name",
getNameTextField());
- addField(Translator.localize("label.namespace"),
+ addField("label.namespace",
getNamespaceSelector());
// the context in which the statemachine resides
@@ -84,14 +84,14 @@
new UMLComboBox2(
getContextComboBoxModel(),
ActionSetContextStateMachine.getInstance());
- addField(Translator.localize("label.context"),
+ addField("label.context",
new UMLComboBoxNavigator(
Translator.localize("label.context.navigate.tooltip"),
contextComboBox));
// the top state
JList topList = new UMLLinkedList(new UMLStateMachineTopListModel());
- addField(Translator.localize("label.top-state"),
+ addField("label.top-state",
new JScrollPane(topList));
addSeparator();
@@ -99,7 +99,7 @@
// the transitions the statemachine has
JList transitionList = new UMLLinkedList(
new UMLStateMachineTransitionListModel());
- addField(Translator.localize("label.transition"),
+ addField("label.transition",
new JScrollPane(transitionList));
// the submachinestates
@@ -107,7 +107,7 @@
// to decide
JList submachineStateList = new UMLLinkedList(
new UMLStateMachineSubmachineStateListModel());
- addField(Translator.localize("label.submachinestate"),
+ addField("label.submachinestate",
new JScrollPane(submachineStateList));
addAction(new ActionNavigateNamespace());
Modified: trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelStubState.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelStubState.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelStubState.java&p2=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelStubState.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelStubState.java (original)
+++ trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelStubState.java 2007-09-12 09:45:16-0700
@@ -1,5 +1,5 @@
// $Id$
-// Copyright (c) 1996-2006 The Regents of the University of California. All
+// Copyright (c) 1996-2007 The Regents of the University of California. All
// Rights Reserved. Permission to use, copy, modify, and distribute this
// software and its documentation without fee, and without a written
// agreement is hereby granted, provided that the above copyright notice
@@ -46,30 +46,30 @@
* Constructor for PropPanelStubState.
*/
public PropPanelStubState() {
- super("Stub State", lookupIcon("StubState"),
+ super("label.stub.state", lookupIcon("StubState"),
ConfigLoader.getTabPropsOrientation());
- addField(Translator.localize("label.name"),
+ addField("label.name",
getNameTextField());
- addField(Translator.localize("label.container"),
+ addField("label.container",
getContainerScroll());
JComboBox referencestateBox =
new UMLComboBox2(
new UMLStubStateComboBoxModel(),
ActionSetStubStateReferenceState.getInstance());
- addField(Translator.localize("label.referencestate"),
+ addField("label.referencestate",
new UMLComboBoxNavigator(
Translator.localize("tooltip.nav-stubstate"),
referencestateBox));
addSeparator();
- addField(Translator.localize("label.incoming"),
+ addField("label.incoming",
getIncomingScroll());
- addField(Translator.localize("label.outgoing"),
+ addField("label.outgoing",
getOutgoingScroll());
}
}
Modified: trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSubmachineState.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSubmachineState.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSubmachineState.java&p2=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSubmachineState.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSubmachineState.java (original)
+++ trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSubmachineState.java 2007-09-12 09:45:16-0700
@@ -1,5 +1,5 @@
// $Id$
-// Copyright (c) 1996-2006 The Regents of the University of California. All
+// Copyright (c) 1996-2007 The Regents of the University of California. All
// Rights Reserved. Permission to use, copy, modify, and distribute this
// software and its documentation without fee, and without a written
// agreement is hereby granted, provided that the above copyright notice
@@ -70,38 +70,38 @@
* Construct a default property panel SubmachineState elements.
*/
public PropPanelSubmachineState() {
- super("Submachine State", lookupIcon("SubmachineState"),
+ super("label.submachinestate", lookupIcon("SubmachineState"),
ConfigLoader.getTabPropsOrientation());
- getTitleLabel().setText("Submachine State");
- addField(Translator.localize("label.name"),
+ getTitleLabel().setText("label.submachinestate");
+ addField("label.name",
getNameTextField());
- addField(Translator.localize("label.container"),
+ addField("label.container",
getContainerScroll());
JComboBox submachineBox = new UMLComboBox2(
new UMLSubmachineStateComboBoxModel(),
ActionSetSubmachineStateSubmachine.getInstance());
- addField(Translator.localize("label.submachine"),
+ addField("label.submachine",
new UMLComboBoxNavigator(Translator.localize(
"tooltip.nav-submachine"), submachineBox));
- addField(Translator.localize("label.entry"),
+ addField("label.entry",
getEntryScroll());
- addField(Translator.localize("label.exit"),
+ addField("label.exit",
getExitScroll());
- addField(Translator.localize("label.do-activity"),
+ addField("label.do-activity",
getDoScroll());
addSeparator();
- addField(Translator.localize("label.incoming"),
+ addField("label.incoming",
getIncomingScroll());
- addField(Translator.localize("label.outgoing"),
+ addField("label.outgoing",
getOutgoingScroll());
- addField(Translator.localize("label.internal-transitions"),
+ addField("label.internal-transitions",
getInternalTransitionsScroll());
addSeparator();
- addField(Translator.localize("label.subvertex"),
+ addField("label.subvertex",
new JScrollPane(new UMLMutableLinkedList(
new UMLCompositeStateSubvertexListModel(), null,
ActionNewStubState.getInstance())));
@@ -133,7 +133,7 @@
Object target =
((TargetManager) e.getSource()).getModelTarget();
if (Model.getFacade().isASubmachineState(target)) {
- getTitleLabel().setText("Submachine State");
+ getTitleLabel().setText("label.submachinestate");
}
}
}
Modified: trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSynchState.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSynchState.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSynchState.java&p2=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSynchState.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSynchState.java (original)
+++ trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelSynchState.java 2007-09-12 09:45:16-0700
@@ -1,5 +1,5 @@
// $Id$
-// Copyright (c) 2004-2006 The Regents of the University of California. All
+// Copyright (c) 2004-2007 The Regents of the University of California. All
// Rights Reserved. Permission to use, copy, modify, and distribute this
// software and its documentation without fee, and without a written
// agreement is hereby granted, provided that the above copyright notice
@@ -24,7 +24,6 @@
package org.argouml.uml.ui.behavior.state_machines;
-import org.argouml.i18n.Translator;
import org.argouml.uml.ui.UMLTextField2;
import org.argouml.util.ConfigLoader;
@@ -44,22 +43,22 @@
* Construct a property panel for a Synch State.
*/
public PropPanelSynchState() {
- super("Synch State",
+ super("label.synch-state",
lookupIcon("SynchState"),
ConfigLoader.getTabPropsOrientation());
- addField(Translator.localize("label.name"),
+ addField("label.name",
getNameTextField());
- addField(Translator.localize("label.container"),
+ addField("label.container",
getContainerScroll());
- addField(Translator.localize("label.bound"),
+ addField("label.bound",
new UMLTextField2(new UMLSynchStateBoundDocument()));
addSeparator();
- addField(Translator.localize("label.incoming"),
+ addField("label.incoming",
getIncomingScroll());
- addField(Translator.localize("label.outgoing"),
+ addField("label.outgoing",
getOutgoingScroll());
}
Modified: trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelTimeEvent.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelTimeEvent.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelTimeEvent.java&p2=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelTimeEvent.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelTimeEvent.java (original)
+++ trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelTimeEvent.java 2007-09-12 09:45:16-0700
@@ -1,5 +1,5 @@
// $Id$
-// Copyright (c) 1996-2006 The Regents of the University of California. All
+// Copyright (c) 1996-2007 The Regents of the University of California. All
// Rights Reserved. Permission to use, copy, modify, and distribute this
// software and its documentation without fee, and without a written
// agreement is hereby granted, provided that the above copyright notice
@@ -27,7 +27,6 @@
import javax.swing.JPanel;
import javax.swing.JScrollPane;
-import org.argouml.i18n.Translator;
import org.argouml.uml.ui.UMLExpressionBodyField;
import org.argouml.uml.ui.UMLExpressionLanguageField;
import org.argouml.uml.ui.UMLExpressionModel2;
@@ -45,7 +44,7 @@
* The constructor.
*/
public PropPanelTimeEvent() {
- super("Time event", lookupIcon("TimeEvent"), ConfigLoader
+ super("label.time.event", lookupIcon("TimeEvent"), ConfigLoader
.getTabPropsOrientation());
}
@@ -57,8 +56,7 @@
UMLExpressionModel2 whenModel = new UMLTimeExpressionModel(
this, "when");
- JPanel whenPanel = createBorderPanel(Translator
- .localize("label.when"));
+ JPanel whenPanel = createBorderPanel("label.when");
whenPanel.add(new JScrollPane(new UMLExpressionBodyField(
whenModel, true)));
whenPanel.add(new UMLExpressionLanguageField(whenModel,
Modified: trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelTransition.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelTransition.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelTransition.java&p2=trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelTransition.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelTransition.java (original)
+++ trunk/src_new/org/argouml/uml/ui/behavior/state_machines/PropPanelTransition.java 2007-09-12 09:45:16-0700
@@ -26,7 +26,6 @@
import javax.swing.JList;
-import org.argouml.i18n.Translator;
import org.argouml.uml.diagram.state.ui.ButtonActionNewCallEvent;
import org.argouml.uml.diagram.state.ui.ButtonActionNewChangeEvent;
import org.argouml.uml.diagram.state.ui.ButtonActionNewSignalEvent;
@@ -62,34 +61,34 @@
* Construct a new property panel for a Transition.
*/
public PropPanelTransition() {
- super("Transition",
+ super("label.transition",
lookupIcon("Transition"),
ConfigLoader.getTabPropsOrientation());
- addField(Translator.localize("label.name"),
+ addField("label.name",
getNameTextField());
- addField(Translator.localize("label.statemachine"),
+ addField("label.statemachine",
getSingleRowScroll(new UMLTransitionStatemachineListModel()));
- addField(Translator.localize("label.state"),
+ addField("label.state",
getSingleRowScroll(new UMLTransitionStateListModel()));
addSeparator();
- addField(Translator.localize("label.source"),
+ addField("label.source",
getSingleRowScroll(new UMLTransitionSourceListModel()));
- addField(Translator.localize("label.target"),
+ addField("label.target",
getSingleRowScroll(new UMLTransitionTargetListModel()));
- addField(Translator.localize("label.trigger"),
+ addField("label.trigger",
getSingleRowScroll( new UMLTransitionTriggerListModel()));
JList guardList = new UMLMutableLinkedList(
new UMLTransitionGuardListModel(), null,
ActionNewGuard.getSingleton());
- addField(Translator.localize("label.guard"),
+ addField("label.guard",
getSingleRowScroll(guardList));
JList effectList = new UMLTransitionEffectList(
new UMLTransitionEffectListModel());
- addField(Translator.localize("label.effect"),
+ addField("label.effect",
getSingleRowScroll(effectList));
addAction(new ActionNavigateContainerElement());
Modified: trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelActor.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelActor.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelActor.java&p2=trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelActor.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelActor.java (original)
+++ trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelActor.java 2007-09-12 09:45:16-0700
@@ -1,5 +1,5 @@
// $Id$
-// Copyright (c) 1996-2006 The Regents of the University of California. All
+// Copyright (c) 1996-2007 The Regents of the University of California. All
// Rights Reserved. Permission to use, copy, modify, and distribute this
// software and its documentation without fee, and without a written
// agreement is hereby granted, provided that the above copyright notice
@@ -24,7 +24,6 @@
package org.argouml.uml.ui.behavior.use_cases;
-import org.argouml.i18n.Translator;
import org.argouml.uml.ui.ActionNavigateContainerElement;
import org.argouml.uml.ui.foundation.core.PropPanelClassifier;
import org.argouml.uml.ui.foundation.extension_mechanisms.ActionNewStereotype;
@@ -48,27 +47,27 @@
* Construct a new property panel for an Actor.
*/
public PropPanelActor() {
- super("Actor", lookupIcon("Actor"),
+ super("label.actor", lookupIcon("Actor"),
ConfigLoader.getTabPropsOrientation());
- addField(Translator.localize("label.name"),
+ addField("label.name",
getNameTextField());
- addField(Translator.localize("label.namespace"),
+ addField("label.namespace",
getNamespaceSelector());
add(getModifiersPanel());
addSeparator();
- addField(Translator.localize("label.generalizations"),
+ addField("label.generalizations",
getGeneralizationScroll());
- addField(Translator.localize("label.specializations"),
+ addField("label.specializations",
getSpecializationScroll());
addSeparator();
- addField(Translator.localize("label.association-ends"),
+ addField("label.association-ends",
getAssociationEndScroll());
// The toolbar buttons that go at the top:
Modified: trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelExtend.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelExtend.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelExtend.java&p2=trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelExtend.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelExtend.java (original)
+++ trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelExtend.java 2007-09-12 09:45:16-0700
@@ -49,11 +49,11 @@
* Builds the property panel for an Extend relationship.<p>
*
* This is a type of Relationship, but, since Relationship has no semantic
- * meaning of its own, we derive directly from PropPanelModelElement (as
- * other children of Relationship do).<p>
+ * meaning of its own, we derive directly from PropPanelModelElement (as
+ * other children of Relationship do).<p>
*
* TODO: this property panel needs refactoring to remove dependency on
- * old gui components.
+ * old GUI components.
*
* @author [email protected]
*/
@@ -72,23 +72,23 @@
*/
public PropPanelExtend() {
- super("Extend", lookupIcon("Extend"),
+ super("label.extend", lookupIcon("Extend"),
ConfigLoader.getTabPropsOrientation());
- addField(Translator.localize("label.name"),
+ addField("label.name",
getNameTextField());
- addField(Translator.localize("label.namespace"),
+ addField("label.namespace",
getNamespaceSelector());
addSeparator();
// Link to the two ends.
- addField(Translator.localize("label.usecase-base"),
+ addField("label.usecase-base",
getSingleRowScroll(new UMLLinkedList(
new UMLExtendBaseListModel())));
- addField(Translator.localize("label.extension"),
+ addField("label.extension",
getSingleRowScroll(new UMLLinkedList(
new UMLExtendExtensionListModel())));
@@ -96,7 +96,7 @@
new UMLMutableLinkedList(new UMLExtendExtensionPointListModel(),
ActionAddExtendExtensionPoint.getInstance(),
ActionNewExtendExtensionPoint.SINGLETON);
- addField(Translator.localize("label.extension-points"),
+ addField("label.extension-points",
new JScrollPane(extensionPointList));
addSeparator();
@@ -110,7 +110,7 @@
JScrollPane conditionScroll =
new JScrollPane(conditionArea);
- addField(Translator.localize("label.condition"), conditionScroll);
+ addField("label.condition", conditionScroll);
// Add the toolbar buttons:
addAction(new ActionNavigateNamespace());
Modified: trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelExtensionPoint.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelExtensionPoint.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelExtensionPoint.java&p2=trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelExtensionPoint.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelExtensionPoint.java (original)
+++ trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelExtensionPoint.java 2007-09-12 09:45:16-0700
@@ -1,5 +1,5 @@
// $Id$
-// Copyright (c) 1996-2006 The Regents of the University of California. All
+// Copyright (c) 1996-2007 The Regents of the University of California. All
// Rights Reserved. Permission to use, copy, modify, and distribute this
// software and its documentation without fee, and without a written
// agreement is hereby granted, provided that the above copyright notice
@@ -60,14 +60,14 @@
* Construct a new property panel for an ExtensionPoint.
*/
public PropPanelExtensionPoint() {
- super("ExtensionPoint", ConfigLoader.getTabPropsOrientation());
+ super("label.extension-point", ConfigLoader.getTabPropsOrientation());
// First column
// nameField, stereotypeBox and namespaceScroll are all set up by
// PropPanelModelElement.
- addField(Translator.localize("label.name"),
+ addField("label.name",
getNameTextField());
// Our location (a String). Allow the location label to
@@ -75,17 +75,17 @@
JTextField locationField = new UMLTextField2(
new UMLExtensionPointLocationDocument());
- addField(Translator.localize("label.location"),
+ addField("label.location",
locationField);
addSeparator();
- addField(Translator.localize("label.usecase-base"),
+ addField("label.usecase-base",
getSingleRowScroll(new UMLExtensionPointUseCaseListModel()));
JList extendList = new UMLLinkedList(
new UMLExtensionPointExtendListModel());
- addField(Translator.localize("label.extend"),
+ addField("label.extend",
new JScrollPane(extendList));
Modified: trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelInclude.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelInclude.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelInclude.java&p2=trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelInclude.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelInclude.java (original)
+++ trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelInclude.java 2007-09-12 09:45:16-0700
@@ -26,7 +26,6 @@
import javax.swing.JList;
-import org.argouml.i18n.Translator;
import org.argouml.model.Model;
import org.argouml.uml.ui.ActionNavigateNamespace;
import org.argouml.uml.ui.UMLLinkedList;
@@ -55,25 +54,25 @@
* Construct a property panel for Include model elements.
*/
public PropPanelInclude() {
- super("Include",
+ super("label.includes",
lookupIcon("Include"),
ConfigLoader.getTabPropsOrientation());
- addField(Translator.localize("label.name"),
+ addField("label.name",
getNameTextField());
- addField(Translator.localize("label.namespace"),
+ addField("label.namespace",
getNamespaceSelector());
addSeparator();
JList baseBox =
new UMLLinkedList(new UMLIncludeBaseListModel());
- addField(Translator.localize("label.usecase-base"),
+ addField("label.usecase-base",
getSingleRowScroll(baseBox));
JList additionBox =
new UMLLinkedList(new UMLIncludeAdditionListModel());
- addField(Translator.localize("label.addition"),
+ addField("label.addition",
getSingleRowScroll(additionBox));
// Add the toolbar buttons:
Modified: trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelUseCase.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelUseCase.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelUseCase.java&p2=trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelUseCase.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelUseCase.java (original)
+++ trunk/src_new/org/argouml/uml/ui/behavior/use_cases/PropPanelUseCase.java 2007-09-12 09:45:16-0700
@@ -28,7 +28,6 @@
import javax.swing.JList;
import javax.swing.JScrollPane;
-import org.argouml.i18n.Translator;
import org.argouml.uml.ui.ActionNavigateNamespace;
import org.argouml.uml.ui.UMLLinkedList;
import org.argouml.uml.ui.UMLMutableLinkedList;
@@ -44,6 +43,7 @@
* This is a type of Classifier, and like other Classifiers can have
* attributes and operations (some processes use these to define
* requirements).<p>
+ *
* <em>Note</em>. ArgoUML does not currently support separate
* compartments on the display for this.<p>
*/
@@ -54,55 +54,55 @@
*/
public PropPanelUseCase() {
// TODO: I18N
- super("UseCase",
+ super("label.usecase",
lookupIcon("UseCase"),
ConfigLoader.getTabPropsOrientation());
- addField(Translator.localize("label.name"),
+ addField("label.name",
getNameTextField());
- addField(Translator.localize("label.namespace"),
+ addField("label.namespace",
getNamespaceSelector());
add(getModifiersPanel());
- addField(Translator.localize("label.client-dependencies"),
+ addField("label.client-dependencies",
getClientDependencyScroll());
- addField(Translator.localize("label.supplier-dependencies"),
+ addField("label.supplier-dependencies",
getSupplierDependencyScroll());
addSeparator();
- addField(Translator.localize("label.generalizations"),
+ addField("label.generalizations",
getGeneralizationScroll());
- addField(Translator.localize("label.specializations"),
+ addField("label.specializations",
getSpecializationScroll());
JList extendsList = new UMLLinkedList(new UMLUseCaseExtendListModel());
- addField(Translator.localize("label.extends"),
+ addField("label.extends",
new JScrollPane(extendsList));
JList includesList =
new UMLLinkedList(
new UMLUseCaseIncludeListModel());
- addField(Translator.localize("label.includes"),
+ addField("label.includes",
new JScrollPane(includesList));
addSeparator();
- addField(Translator.localize("label.attributes"),
+ addField("label.attributes",
getAttributeScroll());
- addField(Translator.localize("label.association-ends"),
+ addField("label.association-ends",
getAssociationEndScroll());
- addField(Translator.localize("label.operations"),
+ addField("label.operations",
getOperationScroll());
JList extensionPoints =
new UMLMutableLinkedList(
new UMLUseCaseExtensionPointListModel(), null,
ActionNewUseCaseExtensionPoint.SINGLETON);
- addField(Translator.localize("label.extension-points"),
+ addField("label.extension-points",
new JScrollPane(extensionPoints));
Modified: trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelAssociation.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelAssociation.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelAssociation.java&p2=trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelAssociation.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelAssociation.java (original)
+++ trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelAssociation.java 2007-09-12 09:45:16-0700
@@ -1,5 +1,5 @@
// $Id$
-// Copyright (c) 1996-2006 The Regents of the University of California. All
+// Copyright (c) 1996-2007 The Regents of the University of California. All
// Rights Reserved. Permission to use, copy, modify, and distribute this
// software and its documentation without fee, and without a written
// agreement is hereby granted, provided that the above copyright notice
@@ -71,23 +71,24 @@
* Construct a property panel for UML Association elements.
*/
public PropPanelAssociation() {
- this("Association", ConfigLoader.getTabPropsOrientation());
- addField(Translator.localize("label.name"),
+ this("label.association",
+ ConfigLoader.getTabPropsOrientation());
+ addField("label.name",
getNameTextField());
- addField(Translator.localize("label.namespace"),
+ addField("label.namespace",
getNamespaceSelector());
add(modifiersPanel);
addSeparator();
- addField(Translator.localize("label.connections"),
+ addField("label.connections",
assocEndScroll);
addSeparator();
- addField(Translator.localize("label.association-roles"),
+ addField("label.association-roles",
associationRoleScroll);
- addField(Translator.localize("label.association-links"),
+ addField("label.association-links",
linksScroll);
addAction(new ActionNavigateContainerElement());
Modified: trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelAssociationClass.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelAssociationClass.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelAssociationClass.java&p2=trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelAssociationClass.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelAssociationClass.java (original)
+++ trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelAssociationClass.java 2007-09-12 09:45:16-0700
@@ -64,7 +64,8 @@
* Construct a property panel for AssociationClass elements.
*/
public PropPanelAssociationClass() {
- super("AssociationClass", lookupIcon("AssociationClass"),
+ super("label.association-class",
+ lookupIcon("AssociationClass"),
ConfigLoader.getTabPropsOrientation());
addField(Translator.localize("label.name"),
Modified: trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelAssociationEnd.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelAssociationEnd.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelAssociationEnd.java&p2=trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelAssociationEnd.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelAssociationEnd.java (original)
+++ trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelAssociationEnd.java 2007-09-12 09:45:16-0700
@@ -135,7 +135,8 @@
* @see java.lang.Object#Object()
*/
public PropPanelAssociationEnd() {
- super("AssociationEnd", ConfigLoader.getTabPropsOrientation());
+ super("label.association-end",
+ ConfigLoader.getTabPropsOrientation());
associationLabel = Translator.localize("label.association");
createControls();
positionStandardControls();
@@ -156,13 +157,13 @@
targetScopeCheckBox = new UMLAssociationEndTargetScopeCheckbox();
aggregationRadioButtonpanel =
new UMLAssociationEndAggregationRadioButtonPanel(
- Translator.localize("label.aggregation"), true);
+ "label.aggregation", true);
changeabilityRadioButtonpanel =
new UMLAssociationEndChangeabilityRadioButtonPanel(
- Translator.localize("label.changeability"), true);
+ "label.changeability", true);
visibilityRadioButtonPanel =
new UMLModelElementVisibilityRadioButtonPanel(
- Translator.localize("label.visibility"), true);
+ "label.visibility", true);
specificationScroll = new JScrollPane(new UMLMutableLinkedList(
new UMLAssociationEndSpecificationListModel(),
ActionAddAssociationSpecification.getInstance(),
@@ -184,22 +185,21 @@
*/
protected void positionControls() {
addField(associationLabel, associationScroll);
- addField(Translator.localize("label.type"), typeCombobox);
- addField(Translator.localize("label.multiplicity"),
+ addField("label.type", typeCombobox);
+ addField("label.multiplicity",
getMultiplicityComboBox());
addSeparator();
- JPanel panel = createBorderPanel(Translator.localize(
- "label.modifiers"));
+ JPanel panel = createBorderPanel("label.modifiers");
panel.add(navigabilityCheckBox);
panel.add(orderingCheckBox);
panel.add(targetScopeCheckBox);
panel.setVisible(true);
add(panel);
- addField(Translator.localize("label.specification"),
+ addField("label.specification",
specificationScroll);
- addField(Translator.localize("label.qualifiers"),
+ addField("label.qualifiers",
qualifiersScroll);
Modified: trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelClass.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelClass.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelClass.java&p2=trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelClass.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelClass.java (original)
+++ trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelClass.java 2007-09-12 09:45:16-0700
@@ -24,7 +24,6 @@
package org.argouml.uml.ui.foundation.core;
-import org.argouml.i18n.Translator;
import org.argouml.uml.ui.ActionNavigateNamespace;
import org.argouml.uml.ui.foundation.extension_mechanisms.ActionNewStereotype;
import org.argouml.util.ConfigLoader;
@@ -43,13 +42,13 @@
* Construct a property panel for UML Class elements.
*/
public PropPanelClass() {
- super("Class",
+ super("label.class",
lookupIcon("Class"),
ConfigLoader.getTabPropsOrientation());
- addField(Translator.localize("label.name"),
+ addField("label.name",
getNameTextField());
- addField(Translator.localize("label.namespace"),
+ addField("label.namespace",
getNamespaceSelector());
getModifiersPanel().add(new UMLClassActiveCheckBox());
add(getModifiersPanel());
@@ -57,24 +56,24 @@
addSeparator();
- addField(Translator.localize("label.client-dependencies"),
+ addField("label.client-dependencies",
getClientDependencyScroll());
- addField(Translator.localize("label.supplier-dependencies"),
+ addField("label.supplier-dependencies",
getSupplierDependencyScroll());
- addField(Translator.localize("label.generalizations"),
+ addField("label.generalizations",
getGeneralizationScroll());
- addField(Translator.localize("label.specializations"),
+ addField("label.specializations",
getSpecializationScroll());
addSeparator();
- addField(Translator.localize("label.attributes"),
+ addField("label.attributes",
getAttributeScroll());
- addField(Translator.localize("label.association-ends"),
+ addField("label.association-ends",
getAssociationEndScroll());
- addField(Translator.localize("label.operations"),
+ addField("label.operations",
getOperationScroll());
- addField(Translator.localize("label.owned-elements"),
+ addField("label.owned-elements",
getOwnedElementsScroll());
addAction(new ActionNavigateNamespace());
Modified: trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelModelElement.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelModelElement.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelModelElement.java&p2=trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelModelElement.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelModelElement.java (original)
+++ trunk/src_new/org/argouml/uml/ui/foundation/core/PropPanelModelElement.java 2007-09-12 09:45:16-0700
@@ -127,29 +127,29 @@
*/
public PropPanelModelElement() {
this("ModelElement", null, ConfigLoader.getTabPropsOrientation());
- addField(Translator.localize("label.name"),
+ addField("label.name",
getNameTextField());
- addField(Translator.localize("label.namespace"),
+ addField("label.namespace",
getNamespaceSelector());
addSeparator();
- addField(Translator.localize("label.supplier-dependencies"),
+ addField("label.supplier-dependencies",
getSupplierDependencyScroll());
- addField(Translator.localize("label.client-dependencies"),
+ addField("label.client-dependencies",
getClientDependencyScroll());
- addField(Translator.localize("label.source-flows"),
+ addField("label.source-flows",
getSourceFlowScroll());
- addField(Translator.localize("label.target-flows"),
+ addField("label.target-flows",
getTargetFlowScroll());
addSeparator();
- addField(Translator.localize("label.constraints"),
+ addField("label.constraints",
getConstraintScroll());
add(getNamespaceVisibilityPanel());
- addField(Translator.localize("label.derived"),
+ addField("label.derived",
new UMLDerivedCheckBox());
}
@@ -169,6 +169,7 @@
/**
* @return a scrollpane for the namespace
* @deprecated use {@link #getNamespaceSelector()}
+ * When was this deprecated? Can it be removed?
*/
protected JComponent getNamespaceScroll() {
if (namespaceScroll == null) {
Modified: trunk/src_new/org/argouml/uml/ui/model_management/PropPanelPackage.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/model_management/PropPanelPackage.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/ui/model_management/PropPanelPackage.java&p2=trunk/src_new/org/argouml/uml/ui/model_management/PropPanelPackage.java&r1=13544&r2=13545
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/model_management/PropPanelPackage.java (original)
+++ trunk/src_new/org/argouml/uml/ui/model_management/PropPanelPackage.java 2007-09-12 09:45:16-0700
@@ -84,7 +84,7 @@
* Construct a default property panel for UML Package elements.
*/
public PropPanelPackage() {
- this("Package", lookupIcon("Package"),
+ this("label.package", lookupIcon("Package"),
ConfigLoader.getTabPropsOrientation());
}
@@ -106,9 +106,9 @@
* should override to place the elements the way they want.
*/
protected void placeElements() {
- addField(Translator.localize("label.name"),
+ addField("label.name",
getNameTextField());
- addField(Translator.localize("label.namespace"),
+ addField("label.namespace",
getNamespaceSelector());
add(getNamespaceVisibilityPanel());
@@ -117,14 +117,14 @@
addSeparator();
- addField(Translator.localize("label.generalizations"),
+ addField("label.generalizations",
getGeneralizationScroll());
- addField(Translator.localize("label.specializations"),
+ addField("label.specializations",
getSpecializationScroll());
addSeparator();
- addField(Translator.localize("label.owned-elements"),
+ addField("label.owned-elements",
getOwnedElementsScroll());
JList importList =
@@ -133,7 +133,7 @@
null,
new ActionRemovePackageImport(),
true);
- addField(Translator.localize("label.imported-elements"),
+ addField("label.imported-elements",
new JScrollPane(importList));
addAction(new ActionNavigateNamespace());
lmpx.com only provides a reader for public news (NNTP) servers. It is not
affiliated with the servers or forums shown here and is not responsible for
the content of articles, which is written by their respective authors.
--- trunk/src_new/org/argouml/ui/StylePanel.java (original)
+++ trunk/src_new/org/argouml/ui/StylePanel.java 2007-09-12 09:45:16-0700
@@ -1,5 +1,5 @@
// $Id$
-// Copyright (c) 1996-2006 The Regents of the University of California. All
+// Copyright (c) 1996-2007 The Regents of the University of California. All
// Rights Reserved. Permission to use, copy, modify, and distribute this
// software and its documentation without fee, and without a written
// agreement is hereby granted, provided that the above copyright notice
@@ -36,6 +36,7 @@
import javax.swing.event.ListSelectionListener;
import org.apache.log4j.Logger;
+import org.argouml.i18n.Translator;
import org.argouml.kernel.Project;
import org.argouml.kernel.ProjectManager;
import org.argouml.model.Model;
@@ -63,23 +64,23 @@
/**
* The constructor.
*
* @param title the panel title
*/
- public StylePanel(String title) {
- super(title);
+ public StylePanel(String tag) {
+ super(Translator.localize(tag));
setLayout(new LabelledLayout());
}
/**
- * Add a seperator.
+ * Add a separator.
*/
protected final void addSeperator() {
add(LabelledLayout.getSeperator());
}
/**
- * This method must be overriden by implementors if they don't want to
- * refresh the whole stylepanel every time a property change events is
+ * This method must be overridden by implementors if they don't want to
+ * refresh the whole style panel every time a property change events is
* fired. The default behavior is to always call {@link #refresh()}.
* @see #refresh()
*/
@@ -63,23 +64,23 @@
* The constructor.
*
- * @param title the panel title
+ * @param tag The localization tag for the panel title.
*/
Modified: trunk/src_new/org/argouml/uml/diagram/use_case/ui/StylePanelFigUseCase.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/diagram/use_case/ui/StylePanelFigUseCase.java?view=diff&rev=13545&p1=trunk/src_new/org/argouml/uml/diagram/use_case/ui/StylePanelFigUseCase.java&p2=trunk/src_new/org/argouml/uml/diagram/use_case/ui/StylePanelFigUseCase.java&r1=13544&r2=13545
==============================================================================